# Generated by Django 3.0.6 on 2021-07-19 10:38

import django.contrib.postgres.indexes
from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0008_alter_file_field'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(null=True, upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
        migrations.AlterField(
            model_name='file',
            name='type',
            field=models.CharField(blank=True, db_index=True, default='file', max_length=10, null=True, verbose_name='Type'),
        ),
        migrations.AddIndex(
            model_name='file',
            index=django.contrib.postgres.indexes.BrinIndex(fields=['creation_date'], name='djangorestf_creatio_af499f_brin'),
        ),
    ]
