# Generated by Django 3.0.4 on 2020-03-18 17:06

from django.db import migrations, models
import djangorestfilemanager.models


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0003_auto_20200311_1022'),
    ]

    operations = [
        migrations.AlterField(
            model_name='file',
            name='file',
            field=models.FileField(null=True, storage=djangorestfilemanager.models.RestFileManagerStorage(location='s3_uploader'), upload_to=djangorestfilemanager.models.set_storage_file_dir, verbose_name='File'),
        ),
    ]
