# Generated by Django 3.0.2 on 2020-04-29 10:20

import django.contrib.postgres.fields.jsonb
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djangorestfilemanager', '0005_auto_20200319_1235'),
    ]

    operations = [
        migrations.AddField(
            model_name='file',
            name='data',
            field=django.contrib.postgres.fields.jsonb.JSONField(blank=True, default=dict, null=True),
        ),
    ]
